pub enum RefDeletePrecondition {
Any,
Immediate(RefTarget),
Direct(Option<ObjectId>),
Peeled(ObjectId),
}Expand description
The compare-and-delete precondition checked for a queued ref delete.
Variants
Any
Any existing direct or symbolic ref may be deleted.
Immediate(RefTarget)
The ref’s immediate target must match exactly.
Direct(Option<ObjectId>)
The ref must be direct. When an object id is supplied, it must match.
Peeled(ObjectId)
The ref may be symbolic, but its peeled direct target must match.